@@ -22,7 +22,8 @@ for header_file in glob.glob('%s/*/*.h' % srcdir) + glob.glob('%s/*.h' % srcdir)
 
 wsf = ['lasso_disco_', 'lasso_dst_', 'lasso_is_', 'lasso_profile_service',
         'lasso_discovery', 'lasso_wsf', 'lasso_interaction', 'lasso_utility',
-        'lasso_sa_', 'lasso_soap_', 'lasso_authentication', 'lasso_wsse' ]
+        'lasso_sa_', 'lasso_soap_', 'lasso_authentication', 'lasso_wsse',
+        'lasso_sec_']
 if enable_wsf:
     wsf = []
 
