@@ -1,4 +1,4 @@
-/* $Id: wsf_profile.h,v 1.6 2005/05/16 13:25:57 nclapies Exp $ 
+/* $Id: wsf_profile.h,v 1.9 2005/09/27 07:57:35 nclapies Exp $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -31,8 +31,11 @@ extern "C" {
 #endif /* __cplusplus */ 
 
 #include <lasso/id-ff/server.h>
+#include <lasso/id-ff/identity.h>
+#include <lasso/id-ff/session.h>
 #include <lasso/xml/soap_envelope.h>
 #include <lasso/xml/soap_binding_provider.h>
+#include <lasso/xml/saml_assertion.h>
 
 #define LASSO_TYPE_WSF_PROFILE (lasso_wsf_profile_get_type())
 #define LASSO_WSF_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), \
@@ -63,6 +66,11 @@ struct _LassoWsfProfile {
 	gchar *msg_url;
 	gchar *msg_body;
 
+	/*< private >*/
+	LassoIdentity *identity;
+	LassoSession  *session;
+	
+	LassoWsfProfilePrivate *private_data;
 };
 
 struct _LassoWsfProfileClass {
@@ -71,25 +79,42 @@ struct _LassoWsfProfileClass {
 
 LASSO_EXPORT GType lasso_wsf_profile_get_type(void);
 
+/* FIXME: Should not be here */
+LASSO_EXPORT gboolean lasso_security_mech_id_is_saml_authentication(
+	const gchar *security_mech_id);
+
+LASSO_EXPORT gint lasso_wsf_profile_add_saml_authentication(LassoWsfProfile *profile,
+	LassoSamlAssertion *credential);
+
+LASSO_EXPORT LassoIdentity* lasso_wsf_profile_get_identity(LassoWsfProfile *profile);
+LASSO_EXPORT LassoSession* lasso_wsf_profile_get_session(LassoWsfProfile *profile);
+LASSO_EXPORT gboolean lasso_wsf_profile_is_identity_dirty(LassoWsfProfile *profile);
+LASSO_EXPORT gboolean lasso_wsf_profile_is_session_dirty(LassoWsfProfile *profile);
+
+LASSO_EXPORT gint lasso_wsf_profile_set_identity_from_dump(LassoWsfProfile *profile,
+	const gchar *dump);
+LASSO_EXPORT gint lasso_wsf_profile_set_session_from_dump(LassoWsfProfile *profile,
+	const gchar *dump);
+
 /* FIXME: must be private method */
-LASSO_EXPORT LassoSoapEnvelope* lasso_wsf_profile_build_soap_envelope(const char *refToMessageId);
+LASSO_EXPORT LassoSoapEnvelope* lasso_wsf_profile_build_soap_envelope(const char *refToMessageId,
+	const char *providerId);
 
 LASSO_EXPORT gint lasso_wsf_profile_build_soap_request_msg(LassoWsfProfile *profile);
 
 LASSO_EXPORT gint lasso_wsf_profile_build_soap_response_msg(LassoWsfProfile *profile);
 
 LASSO_EXPORT gint lasso_wsf_profile_init_soap_request(LassoWsfProfile *profile,
-						      LassoNode *request);
+	LassoNode *request);
 
 LASSO_EXPORT gint lasso_wsf_profile_process_soap_request_msg(LassoWsfProfile *profile,
-							     const gchar *message);
+	const gchar *message, const gchar *security_mech_id);
 
 LASSO_EXPORT gint lasso_wsf_profile_process_soap_response_msg(LassoWsfProfile *profile,
-							      const gchar *message);
+	const gchar *message);
 
 LASSO_EXPORT LassoSoapBindingProvider* lasso_wsf_profile_set_provider_soap_request(
-	LassoWsfProfile *profile,
-	const char *providerId);
+	LassoWsfProfile *profile, const char *providerId);
 
 LASSO_EXPORT LassoWsfProfile* lasso_wsf_profile_new(LassoServer *server);
 
