@@ -1,12 +1,11 @@
-/* $Id: saml_subject_confirmation.h,v 1.2 2004/07/22 06:59:03 eraviart Exp $ 
+/* $Id: saml_subject_confirmation.h,v 1.7 2005/01/22 15:57:55 eraviart Exp $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
- * Copyright (C) 2004 Entr'ouvert
+ * Copyright (C) 2004, 2005 Entr'ouvert
  * http://lasso.entrouvert.org
  * 
- * Authors: Nicolas Clapies <nclapies@entrouvert.com>
- *          Valery Febvre <vfebvre@easter-eggs.com>
+ * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,33 +32,39 @@ extern "C" {
 #include <lasso/xml/xml.h>
 
 #define LASSO_TYPE_SAML_SUBJECT_CONFIRMATION (lasso_saml_subject_confirmation_get_type())
-#define LASSO_SAML_SUBJECT_CONFIRMATION(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, LassoSamlSubjectConfirmation))
-#define LASSO_SAML_SUBJECT_CONFIRMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, LassoSamlSubjectConfirmationClass))
-#define LASSO_IS_SAML_SUBJECT_CONFIRMATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION))
-#define LASSO_IS_SAML_SUBJECT_CONFIRMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION))
-#define LASSO_SAML_SUBJECT_CONFIRMATION_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, LassoSamlSubjectConfirmationClass)) 
+#define LASSO_SAML_SUBJECT_CONFIRMATION(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST((obj), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, \
+				    LassoSamlSubjectConfirmation))
+#define LASSO_SAML_SUBJECT_CONFIRMATION_CLASS(klass) \
+	(G_TYPE_CHECK_CLASS_CAST((klass), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, \
+				 LassoSamlSubjectConfirmationClass))
+#define LASSO_IS_SAML_SUBJECT_CONFIRMATION(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE((obj), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION))
+#define LASSO_IS_SAML_SUBJECT_CONFIRMATION_CLASS(klass) \
+	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION))
+#define LASSO_SAML_SUBJECT_CONFIRMATION_GET_CLASS(o) \
+	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, \
+				    LassoSamlSubjectConfirmationClass)) 
 
 typedef struct _LassoSamlSubjectConfirmation LassoSamlSubjectConfirmation;
 typedef struct _LassoSamlSubjectConfirmationClass LassoSamlSubjectConfirmationClass;
 
 struct _LassoSamlSubjectConfirmation {
-  LassoNode parent;
-  /*< private >*/
+	LassoNode parent;
+
+	/*< public >*/
+	/* <element ref="saml:ConfirmationMethod" maxOccurs="unbounded"/> */
+	GList *ConfirmationMethod;
+	/* <element ref="saml:SubjectConfirmationData" minOccurs="0"/> */
+	char *SubjectConfirmationData;
 };
 
 struct _LassoSamlSubjectConfirmationClass {
-  LassoNodeClass parent;
-  /*< vtable >*/
+	LassoNodeClass parent;
 };
 
 LASSO_EXPORT GType lasso_saml_subject_confirmation_get_type(void);
-LASSO_EXPORT LassoNode* lasso_saml_subject_confirmation_new(void);
-
-LASSO_EXPORT void lasso_saml_subject_confirmation_add_confirmationMethod        (LassoSamlSubjectConfirmation *node,
-										 const xmlChar *confirmationMethod);
-
-LASSO_EXPORT void lasso_saml_subject_confirmation_set_subjectConfirmationMethod (LassoSamlSubjectConfirmation *node,
-										 const xmlChar *subjectConfirmationMethod);
+LASSO_EXPORT LassoSamlSubjectConfirmation* lasso_saml_subject_confirmation_new(void);
 
 #ifdef __cplusplus
 }
