@@ -1,12 +1,11 @@
-/* $Id: samlp_response.h,v 1.3 2004/07/22 06:59:03 eraviart Exp $ 
+/* $Id: samlp_response.h,v 1.10 2005/01/22 15:57:55 eraviart Exp $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
- * Copyright (C) 2004 Entr'ouvert
+ * Copyright (C) 2004, 2005 Entr'ouvert
  * http://lasso.entrouvert.org
  * 
- * Authors: Nicolas Clapies <nclapies@entrouvert.com>
- *          Valery Febvre <vfebvre@easter-eggs.com>
+ * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,34 +31,40 @@ extern "C" {
 
 #include <lasso/xml/samlp_response_abstract.h>
 #include <lasso/xml/samlp_status.h>
+#include <lasso/xml/saml_assertion.h>
 
 #define LASSO_TYPE_SAMLP_RESPONSE (lasso_samlp_response_get_type())
-#define LASSO_SAMLP_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), LASSO_TYPE_SAMLP_RESPONSE, LassoSamlpResponse))
-#define LASSO_SAMLP_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), LASSO_TYPE_SAMLP_RESPONSE, LassoSamlpResponseClass))
-#define LASSO_IS_SAMLP_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), LASSO_TYPE_SAMLP_RESPONSE))
-#define LASSO_IS_SAMLP_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAMLP_RESPONSE))
-#define LASSO_SAMLP_RESPONSE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAMLP_RESPONSE, LassoSamlpResponseClass)) 
+#define LASSO_SAMLP_RESPONSE(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST((obj), LASSO_TYPE_SAMLP_RESPONSE, LassoSamlpResponse))
+#define LASSO_SAMLP_RESPONSE_CLASS(klass) \
+	(G_TYPE_CHECK_CLASS_CAST((klass), LASSO_TYPE_SAMLP_RESPONSE, LassoSamlpResponseClass))
+#define LASSO_IS_SAMLP_RESPONSE(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE((obj), LASSO_TYPE_SAMLP_RESPONSE))
+#define LASSO_IS_SAMLP_RESPONSE_CLASS(klass) \
+	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAMLP_RESPONSE))
+#define LASSO_SAMLP_RESPONSE_GET_CLASS(o) \
+	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAMLP_RESPONSE, LassoSamlpResponseClass)) 
 
 typedef struct _LassoSamlpResponse LassoSamlpResponse;
 typedef struct _LassoSamlpResponseClass LassoSamlpResponseClass;
 
 struct _LassoSamlpResponse {
-  LassoSamlpResponseAbstract parent;
-  /*< private >*/
+	LassoSamlpResponseAbstract parent;
+
+	/*< public >*/
+	/* <element ref="samlp:Status"/> */
+	LassoSamlpStatus *Status;
+	/* <element ref="saml:Assertion" minOccurs="0" maxOccurs="unbounded"/> */
+	GList *Assertion; /* of LassoSamlAssertion* */
 };
 
 struct _LassoSamlpResponseClass {
-  LassoSamlpResponseAbstractClass parent;
+	LassoSamlpResponseAbstractClass parent;
 };
 
 LASSO_EXPORT GType lasso_samlp_response_get_type(void);
-LASSO_EXPORT LassoNode* lasso_samlp_response_new(void);
+LASSO_EXPORT LassoSamlpResponseAbstract* lasso_samlp_response_new(void);
 
-LASSO_EXPORT void lasso_samlp_response_add_assertion (LassoSamlpResponse *node,
-						      gpointer assertion);
-
-LASSO_EXPORT void lasso_samlp_response_set_status    (LassoSamlpResponse *node,
-						      LassoSamlpStatus *status);
 
 #ifdef __cplusplus
 }
